Learn R Programming

covid19swiss (version 0.1.0)

get_info_covid19swiss: Get information about the datasets provided by covid19swiss

Description

Returns information about the datasets in this package for covid19R harvesting

Usage

get_info_covid19swiss()

Arguments

Value

a data.frame of information about the datasets in this package

Examples

Run this code
# NOT RUN {
get_info_covid19swiss()
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab