Learn R Programming

covid19swiss (version 0.1.0)

update_swiss_data: Update the Package Datasets

Description

Checks if new data is available on the package dev version (Github). In case new data is available the function will enable the user the update the datasets

Usage

update_swiss_data()

Arguments

Examples

Run this code
# NOT RUN {
update_swiss_data()

# }

Run the code above in your browser using DataLab