powered by
Returns information about the datasets in this package for covid19R harvesting
get_info_covid19swiss()
a data.frame of information about the datasets in this package
# NOT RUN { get_info_covid19swiss() # } # NOT RUN { # }
Run the code above in your browser using DataLab